package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERSet;
import cn.com.infosec.asn1.DERString;
import cn.com.infosec.asn1.DERUniversalString;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.util.Strings;
import cn.com.infosec.util.encoders.Hex;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;

public class X509Name extends ASN1Encodable {
   public static final DERObjectIdentifier C;
   public static final DERObjectIdentifier O;
   public static final DERObjectIdentifier OU;
   public static final DERObjectIdentifier T;
   public static final DERObjectIdentifier CN;
   public static final DERObjectIdentifier SN;
   public static final DERObjectIdentifier STREET;
   public static final DERObjectIdentifier SERIALNUMBER;
   public static final DERObjectIdentifier L;
   public static final DERObjectIdentifier ST;
   public static final DERObjectIdentifier SURNAME;
   public static final DERObjectIdentifier GIVENNAME;
   public static final DERObjectIdentifier INITIALS;
   public static final DERObjectIdentifier GENERATION;
   public static final DERObjectIdentifier UNIQUE_IDENTIFIER;
   public static final DERObjectIdentifier BUSINESS_CATEGORY;
   public static final DERObjectIdentifier POSTAL_CODE;
   public static final DERObjectIdentifier DN_QUALIFIER;
   public static final DERObjectIdentifier PSEUDONYM;
   public static final DERObjectIdentifier DATE_OF_BIRTH;
   public static final DERObjectIdentifier PLACE_OF_BIRTH;
   public static final DERObjectIdentifier GENDER;
   public static final DERObjectIdentifier COUNTRY_OF_CITIZENSHIP;
   public static final DERObjectIdentifier COUNTRY_OF_RESIDENCE;
   public static final DERObjectIdentifier NAME_AT_BIRTH;
   public static final DERObjectIdentifier POSTAL_ADDRESS;
   public static final DERObjectIdentifier EmailAddress;
   public static final DERObjectIdentifier UnstructuredName;
   public static final DERObjectIdentifier UnstructuredAddress;
   public static final DERObjectIdentifier E;
   public static final DERObjectIdentifier DC;
   public static final DERObjectIdentifier UID;
   public static boolean DefaultReverse;
   public static final Hashtable DefaultSymbols;
   public static final Hashtable RFC2253Symbols;
   public static final Hashtable RFC1779Symbols;
   public static final Hashtable DefaultLookUp;
   /** @deprecated */
   public static final Hashtable OIDLookUp;
   /** @deprecated */
   public static final Hashtable SymbolLookUp;
   private static final Boolean TRUE;
   private static final Boolean FALSE;
   private X509NameEntryConverter converter;
   private Vector ordering;
   private Vector values;
   private Vector added;
   private ASN1Sequence seq;

   static {
      DERObjectIdentifier var0;
      DERObjectIdentifier var10000 = var0 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.6");
      C = var10000;
      DERObjectIdentifier var1;
      var10000 = var1 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.10");
      O = var10000;
      DERObjectIdentifier var2;
      var10000 = var2 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.11");
      OU = var10000;
      DERObjectIdentifier var3;
      var10000 = var3 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.12");
      T = var10000;
      DERObjectIdentifier var4;
      var10000 = var4 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.3");
      CN = var10000;
      DERObjectIdentifier var5;
      var10000 = var5 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.5");
      SN = var10000;
      DERObjectIdentifier var6;
      DERObjectIdentifier var10001 = var6 = new DERObjectIdentifier;
      var10001.<init>("2.5.4.9");
      STREET = var10001;
      SERIALNUMBER = var10000;
      DERObjectIdentifier var7;
      var10000 = var7 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.7");
      L = var10000;
      DERObjectIdentifier var8;
      var10000 = var8 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.8");
      ST = var10000;
      DERObjectIdentifier var9;
      var10000 = var9 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.4");
      SURNAME = var10000;
      DERObjectIdentifier var10;
      var10000 = var10 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.42");
      GIVENNAME = var10000;
      DERObjectIdentifier var11;
      var10000 = var11 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.43");
      INITIALS = var10000;
      DERObjectIdentifier var12;
      var10000 = var12 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.44");
      GENERATION = var10000;
      DERObjectIdentifier var13;
      var10000 = var13 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.45");
      UNIQUE_IDENTIFIER = var10000;
      DERObjectIdentifier var14;
      var10000 = var14 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.15");
      BUSINESS_CATEGORY = var10000;
      DERObjectIdentifier var15;
      var10000 = var15 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.17");
      POSTAL_CODE = var10000;
      DERObjectIdentifier var16;
      var10000 = var16 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.46");
      DN_QUALIFIER = var10000;
      DERObjectIdentifier var17;
      var10000 = var17 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.65");
      PSEUDONYM = var10000;
      DERObjectIdentifier var18;
      var10000 = var18 = new DERObjectIdentifier;
      var10000.<init>("1.3.6.1.5.5.7.9.1");
      DATE_OF_BIRTH = var10000;
      DERObjectIdentifier var19;
      var10000 = var19 = new DERObjectIdentifier;
      var10000.<init>("1.3.6.1.5.5.7.9.2");
      PLACE_OF_BIRTH = var10000;
      DERObjectIdentifier var20;
      var10000 = var20 = new DERObjectIdentifier;
      var10000.<init>("1.3.6.1.5.5.7.9.3");
      GENDER = var10000;
      DERObjectIdentifier var21;
      var10000 = var21 = new DERObjectIdentifier;
      var10000.<init>("1.3.6.1.5.5.7.9.4");
      COUNTRY_OF_CITIZENSHIP = var10000;
      DERObjectIdentifier var22;
      var10000 = var22 = new DERObjectIdentifier;
      var10000.<init>("1.3.6.1.5.5.7.9.5");
      COUNTRY_OF_RESIDENCE = var10000;
      DERObjectIdentifier var23;
      var10000 = var23 = new DERObjectIdentifier;
      var10000.<init>("1.3.36.8.3.14");
      NAME_AT_BIRTH = var10000;
      DERObjectIdentifier var24;
      var10000 = var24 = new DERObjectIdentifier;
      var10000.<init>("2.5.4.16");
      POSTAL_ADDRESS = var10000;
      DERObjectIdentifier var25;
      var10000 = EmailAddress = var25 = PKCSObjectIdentifiers.pkcs_9_at_emailAddress;
      DERObjectIdentifier var26;
      UnstructuredName = var26 = PKCSObjectIdentifiers.pkcs_9_at_unstructuredName;
      DERObjectIdentifier var27;
      UnstructuredAddress = var27 = PKCSObjectIdentifiers.pkcs_9_at_unstructuredAddress;
      E = var10000;
      DERObjectIdentifier var28;
      var10000 = var28 = new DERObjectIdentifier;
      var10000.<init>("0.9.2342.19200300.100.1.25");
      DC = var10000;
      DERObjectIdentifier var29;
      var10000 = var29 = new DERObjectIdentifier;
      var10000.<init>("0.9.2342.19200300.100.1.1");
      UID = var10000;
      DefaultReverse = false;
      Hashtable var30;
      Hashtable var34 = var30 = new Hashtable;
      var34.<init>();
      DefaultSymbols = var34;
      Hashtable var31;
      var34 = var31 = new Hashtable;
      var34.<init>();
      RFC2253Symbols = var34;
      Hashtable var32;
      var34 = var32 = new Hashtable;
      var34.<init>();
      RFC1779Symbols = var34;
      Hashtable var33;
      var34 = var33 = new Hashtable;
      var33.<init>();
      DefaultLookUp = var33;
      OIDLookUp = var30;
      SymbolLookUp = var33;
      TRUE = new Boolean(true);
      FALSE = new Boolean(false);
      var30.put(var0, "C");
      var30.put(var1, "O");
      var30.put(var3, "T");
      var30.put(var2, "OU");
      var30.put(var4, "CN");
      var30.put(var7, "L");
      var30.put(var8, "ST");
      var30.put(var5, "SERIALNUMBER");
      var30.put(var25, "E");
      var30.put(var28, "DC");
      var30.put(var29, "UID");
      var30.put(var6, "STREET");
      var30.put(var9, "SURNAME");
      var30.put(var10, "GIVENNAME");
      var30.put(var11, "INITIALS");
      var30.put(var12, "GENERATION");
      var30.put(var27, "unstructuredAddress");
      var30.put(var26, "unstructuredName");
      var30.put(var13, "UniqueIdentifier");
      var30.put(var16, "DN");
      var30.put(var17, "Pseudonym");
      var30.put(var24, "PostalAddress");
      var30.put(var23, "NameAtBirth");
      var30.put(var21, "CountryOfCitizenship");
      var30.put(var22, "CountryOfResidence");
      var30.put(var20, "Gender");
      var30.put(var19, "PlaceOfBirth");
      var30.put(var18, "DateOfBirth");
      var30.put(var15, "PostalCode");
      var30.put(var14, "BusinessCategory");
      var31.put(var0, "C");
      var31.put(var1, "O");
      var31.put(var2, "OU");
      var31.put(var4, "CN");
      var31.put(var7, "L");
      var31.put(var8, "ST");
      var31.put(var6, "STREET");
      var31.put(var28, "DC");
      var31.put(var29, "UID");
      var32.put(var0, "C");
      var32.put(var1, "O");
      var32.put(var2, "OU");
      var32.put(var4, "CN");
      var32.put(var7, "L");
      var32.put(var8, "ST");
      var32.put(var6, "STREET");
      var34.put("c", var0);
      var34.put("o", var1);
      var34.put("t", var3);
      var34.put("ou", var2);
      var34.put("cn", var4);
      var34.put("l", var7);
      var34.put("st", var8);
      var34.put("sn", var5);
      var34.put("serialnumber", var5);
      var34.put("street", var6);
      var34.put("emailaddress", var25);
      var34.put("dc", var28);
      var34.put("e", var25);
      var34.put("uid", var29);
      var34.put("surname", var9);
      var34.put("givenname", var10);
      var34.put("initials", var11);
      var34.put("generation", var12);
      var34.put("unstructuredaddress", var27);
      var34.put("unstructuredname", var26);
      var34.put("uniqueidentifier", var13);
      var34.put("dn", var16);
      var34.put("pseudonym", var17);
      var34.put("postaladdress", var24);
      var34.put("nameofbirth", var23);
      var34.put("countryofcitizenship", var21);
      var34.put("countryofresidence", var22);
      var34.put("gender", var20);
      var34.put("placeofbirth", var19);
      var34.put("dateofbirth", var18);
      var34.put("postalcode", var15);
      var34.put("businesscategory", var14);
   }

   public static X509Name getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static X509Name getInstance(Object obj) {
      if (obj != null && !(obj instanceof X509Name)) {
         if (obj instanceof ASN1Sequence) {
            return new X509Name((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (X509Name)obj;
      }
   }

   public X509Name(ASN1Sequence seq) {
      this.converter = null;
      Vector var2;
      var2 = new Vector.<init>();
      this.ordering = var2;
      var2 = new Vector.<init>();
      this.values = var2;
      var2 = new Vector.<init>();
      this.added = var2;
      this.seq = seq;
      Enumeration seq1 = seq.getObjects();

      while(seq1.hasMoreElements()) {
         ASN1Set var7 = ASN1Set.getInstance(seq1.nextElement());

         for(int var3 = 0; var3 < var7.size(); ++var3) {
            ASN1Sequence var4;
            if ((var4 = ASN1Sequence.getInstance(var7.getObjectAt(var3))).size() != 2) {
               throw new IllegalArgumentException("badly sized pair");
            }

            this.ordering.addElement(DERObjectIdentifier.getInstance(var4.getObjectAt(0)));
            DEREncodable var8;
            if ((var8 = var4.getObjectAt(1)) instanceof DERString && !(var8 instanceof DERUniversalString)) {
               String var9;
               if ((var9 = ((DERString)var8).getString()).charAt(0) == '#') {
                  this.values.addElement("\\" + var9);
               } else {
                  this.values.addElement(var9);
               }
            } else {
               Vector var10000 = this.values;
               StringBuffer var5;
               StringBuffer var10001 = var5 = new StringBuffer;
               var5.<init>("#");
               var10000.addElement(var10001.append(this.bytesToString(Hex.encode(var8.getDERObject().getDEREncoded()))).toString());
            }

            Vector var10 = this.added;
            Boolean var11;
            if (var3 != 0) {
               var11 = TRUE;
            } else {
               var11 = FALSE;
            }

            var10.addElement(var11);
         }
      }

   }

   /** @deprecated */
   public X509Name(Hashtable attributes) {
      this((Vector)null, (Hashtable)attributes);
   }

   public X509Name(Vector ordering, Hashtable attributes) {
      X509Name var10000 = this;
      X509DefaultEntryConverter var3;
      var3 = new X509DefaultEntryConverter.<init>();
      var10000.<init>(ordering, (Hashtable)attributes, var3);
   }

   public X509Name(Vector ordering, Hashtable attributes, X509NameEntryConverter converter) {
      this.converter = null;
      Vector var4;
      var4 = new Vector.<init>();
      this.ordering = var4;
      var4 = new Vector.<init>();
      this.values = var4;
      var4 = new Vector.<init>();
      this.added = var4;
      this.converter = converter;
      if (ordering != null) {
         for(int converter1 = 0; converter1 != ordering.size(); ++converter1) {
            this.ordering.addElement(ordering.elementAt(converter1));
            this.added.addElement(FALSE);
         }
      } else {
         Enumeration ordering1 = attributes.keys();

         while(ordering1.hasMoreElements()) {
            this.ordering.addElement(ordering1.nextElement());
            this.added.addElement(FALSE);
         }
      }

      for(int ordering2 = 0; ordering2 != this.ordering.size(); ++ordering2) {
         DERObjectIdentifier converter2;
         if (attributes.get(converter2 = (DERObjectIdentifier)this.ordering.elementAt(ordering2)) == null) {
            throw new IllegalArgumentException("No attribute for object id - " + converter2.getId() + " - passed to distinguished name");
         }

         this.values.addElement(attributes.get(converter2));
      }

   }

   public X509Name(Vector oids, Vector values) {
      X509Name var10000 = this;
      X509DefaultEntryConverter var3;
      var3 = new X509DefaultEntryConverter.<init>();
      var10000.<init>(oids, (Vector)values, var3);
   }

   public X509Name(Vector oids, Vector values, X509NameEntryConverter converter) {
      this.converter = null;
      this.ordering = new Vector();
      this.values = new Vector();
      this.added = new Vector();
      this.converter = converter;
      if (oids.size() != values.size()) {
         throw new IllegalArgumentException("oids vector must be same length as values.");
      } else {
         for(int converter1 = 0; converter1 < oids.size(); ++converter1) {
            this.ordering.addElement(oids.elementAt(converter1));
            this.values.addElement(values.elementAt(converter1));
            this.added.addElement(FALSE);
         }

      }
   }

   private Boolean isEncoded(String s) {
      return s.charAt(0) == '#' ? TRUE : FALSE;
   }

   public X509Name(String dirName) {
      this(DefaultReverse, DefaultLookUp, dirName);
   }

   public X509Name(String dirName, X509NameEntryConverter converter) {
      this(DefaultReverse, DefaultLookUp, dirName, converter);
   }

   public X509Name(boolean reverse, String dirName) {
      this(reverse, DefaultLookUp, dirName);
   }

   public X509Name(boolean reverse, String dirName, X509NameEntryConverter converter) {
      this(reverse, DefaultLookUp, dirName, converter);
   }

   public X509Name(boolean reverse, Hashtable lookUp, String dirName) {
      X509Name var10000 = this;
      X509DefaultEntryConverter var4;
      var4 = new X509DefaultEntryConverter.<init>();
      var10000.<init>(reverse, lookUp, dirName, var4);
   }

   private DERObjectIdentifier decodeOID(String name, Hashtable lookUp) {
      if (Strings.toUpperCase(name).startsWith("OID.")) {
         return new DERObjectIdentifier(name.substring(4));
      } else if (name.charAt(0) >= '0' && name.charAt(0) <= '9') {
         return new DERObjectIdentifier(name);
      } else {
         DERObjectIdentifier var3;
         if ((var3 = (DERObjectIdentifier)lookUp.get(Strings.toLowerCase(name))) != null) {
            return var3;
         } else {
            throw new IllegalArgumentException("Unknown object id - " + name + " - passed to distinguished name");
         }
      }
   }

   public X509Name(boolean reverse, Hashtable lookUp, String dirName, X509NameEntryConverter converter) {
      this.converter = null;
      Vector var5;
      var5 = new Vector.<init>();
      this.ordering = var5;
      var5 = new Vector.<init>();
      this.values = var5;
      var5 = new Vector.<init>();
      this.added = var5;
      this.converter = converter;
      X509NameTokenizer converter1;
      converter1 = new X509NameTokenizer.<init>(dirName);

      int var13;
      while(converter1.hasMoreTokens()) {
         if ((var13 = (dirName = converter1.nextToken()).indexOf(61)) == -1) {
            throw new IllegalArgumentException("badly formated directory string");
         }

         String var10000 = dirName;
         dirName = dirName.substring(0, var13);
         String var14;
         var10000 = var14 = var10000.substring(var13 + 1);
         DERObjectIdentifier dirName1 = this.decodeOID(dirName, lookUp);
         if (var10000.indexOf(43) > 0) {
            X509NameTokenizer var6;
            X509NameTokenizer var10003 = var6 = new X509NameTokenizer;
            var10003.<init>(var14, '+');
            var14 = var10003.nextToken();
            this.ordering.addElement(dirName1);
            this.values.addElement(var14);
            this.added.addElement(FALSE);

            while(var6.hasMoreTokens()) {
               String var15 = dirName = var6.nextToken();
               int var10004 = var13 = var15.indexOf(61);
               dirName = dirName.substring(0, var13);
               var14 = var15.substring(var10004 + 1);
               this.ordering.addElement(this.decodeOID(dirName, lookUp));
               this.values.addElement(var14);
               this.added.addElement(TRUE);
            }
         } else {
            this.ordering.addElement(dirName1);
            this.values.addElement(var14);
            this.added.addElement(FALSE);
         }
      }

      if (reverse) {
         Vector reverse1;
         reverse1 = new Vector.<init>();
         Vector lookUp1;
         lookUp1 = new Vector.<init>();
         Vector dirName2;
         dirName2 = new Vector.<init>();
         int converter2 = 1;

         for(var13 = 0; var13 < this.ordering.size(); ++var13) {
            if ((Boolean)this.added.elementAt(var13)) {
               reverse1.insertElementAt(this.ordering.elementAt(var13), converter2);
               lookUp1.insertElementAt(this.values.elementAt(var13), converter2);
               dirName2.insertElementAt(this.added.elementAt(var13), converter2);
               ++converter2;
            } else {
               reverse1.insertElementAt(this.ordering.elementAt(var13), 0);
               lookUp1.insertElementAt(this.values.elementAt(var13), 0);
               dirName2.insertElementAt(this.added.elementAt(var13), 0);
               converter2 = 1;
            }
         }

         this.ordering = reverse1;
         this.values = lookUp1;
         this.added = dirName2;
      }

   }

   private boolean equivalentStrings(String s1, String s2) {
      return (s1 = Strings.toLowerCase(s1.trim())).equals(s2 = Strings.toLowerCase(s2.trim())) || this.stripInternalSpaces(s1).equals(this.stripInternalSpaces(s2));
   }

   private String stripInternalSpaces(String str) {
      StringBuffer var4;
      var4 = new StringBuffer.<init>();
      if (str.length() != 0) {
         char var2;
         var4.append(var2 = str.charAt(0));

         for(int var3 = 1; var3 < str.length(); ++var3) {
            char var10000 = var2;
            var2 = str.charAt(var3);
            if (var10000 != ' ' || var2 != ' ') {
               var4.append(var2);
            }
         }
      }

      return var4.toString();
   }

   private void appendValue(StringBuffer buf, Hashtable oidSymbols, DERObjectIdentifier oid, String value) {
      String var5;
      if ((var5 = (String)oidSymbols.get(oid)) != null) {
         buf.append(var5);
      } else {
         buf.append(oid.getId());
      }

      buf.append('=');
      int var6 = buf.length();
      buf.append(value);
      int oidSymbols1 = buf.length();
      if (value.length() >= 2 && value.charAt(0) == '\\' && value.charAt(1) == '#') {
         var6 += 2;
      }

      for(; var6 != oidSymbols1; ++var6) {
         if (buf.charAt(var6) == ',' || buf.charAt(var6) == '"' || buf.charAt(var6) == '\\' || buf.charAt(var6) == '+' || buf.charAt(var6) == '<' || buf.charAt(var6) == '>' || buf.charAt(var6) == ';') {
            buf.insert(var6, "\\");
            ++var6;
            ++oidSymbols1;
         }
      }

   }

   private String bytesToString(byte[] data) {
      int var4;
      char[] var2 = new char[var4 = data.length];

      for(int var3 = 0; var3 != var4; ++var3) {
         var2[var3] = (char)(data[var3] & 255);
      }

      return new String(var2);
   }

   public Vector getOIDs() {
      Vector var1;
      var1 = new Vector.<init>();

      for(int var2 = 0; var2 != this.ordering.size(); ++var2) {
         var1.addElement(this.ordering.elementAt(var2));
      }

      return var1;
   }

   public Vector getValues() {
      Vector var1;
      var1 = new Vector.<init>();

      for(int var2 = 0; var2 != this.values.size(); ++var2) {
         var1.addElement(this.values.elementAt(var2));
      }

      return var1;
   }

   public Vector getValues(DERObjectIdentifier oid) {
      Vector var2;
      var2 = new Vector.<init>();

      for(int var3 = 0; var3 != this.values.size(); ++var3) {
         if (this.ordering.elementAt(var3).equals(oid)) {
            String var4;
            if ((var4 = (String)this.values.elementAt(var3)).length() > 2 && var4.charAt(0) == '\\' && var4.charAt(1) == '#') {
               var2.addElement(var4.substring(1));
            } else {
               var2.addElement(var4);
            }
         }
      }

      return var2;
   }

   public DERObject toASN1Object() {
      if (this.seq == null) {
         ASN1EncodableVector var1;
         var1 = new ASN1EncodableVector.<init>();
         ASN1EncodableVector var2;
         var2 = new ASN1EncodableVector.<init>();
         DERObjectIdentifier var3 = null;

         DERObjectIdentifier var5;
         for(int var4 = 0; var4 != this.ordering.size(); var3 = var5) {
            ASN1EncodableVector var8;
            ASN1EncodableVector var10001 = var8 = new ASN1EncodableVector;
            var8.<init>();
            var8.add(var5 = (DERObjectIdentifier)this.ordering.elementAt(var4));
            String var6 = (String)this.values.elementAt(var4);
            var10001.add(this.converter.getConvertedValue(var5, var6));
            DERSequence var11;
            if (var3 != null && !(Boolean)this.added.elementAt(var4)) {
               DERSet var12;
               var12 = new DERSet.<init>(var2);
               var1.add(var12);
               ASN1EncodableVector var10 = var2 = new ASN1EncodableVector;
               var10.<init>();
               var11 = new DERSequence.<init>(var8);
               var10.add(var11);
            } else {
               var11 = new DERSequence.<init>(var8);
               var2.add(var11);
            }

            ++var4;
         }

         DERSet var9;
         var9 = new DERSet.<init>(var2);
         var1.add(var9);
         DERSequence var7;
         var7 = new DERSequence.<init>(var1);
         this.seq = var7;
      }

      return this.seq;
   }

   public boolean equals(Object obj, boolean inOrder) {
      if (!inOrder) {
         return this.equals(obj);
      } else if (obj == this) {
         return true;
      } else if (!(obj instanceof X509Name) && !(obj instanceof ASN1Sequence)) {
         return false;
      } else {
         DERObject inOrder1 = ((DEREncodable)obj).getDERObject();
         if (this.getDERObject().equals(inOrder1)) {
            return true;
         } else {
            X509Name var10000;
            X509Name var10001;
            try {
               var10000 = this;
               var10001 = getInstance(obj);
            } catch (IllegalArgumentException var4) {
               return false;
            }

            X509Name obj1 = var10001;
            int inOrder2;
            if ((inOrder2 = var10000.ordering.size()) != obj1.ordering.size()) {
               return false;
            } else {
               for(int var3 = 0; var3 < inOrder2; ++var3) {
                  if (!((DERObjectIdentifier)this.ordering.elementAt(var3)).equals((DERObjectIdentifier)obj1.ordering.elementAt(var3))) {
                     return false;
                  }

                  if (!this.equivalentStrings((String)this.values.elementAt(var3), (String)obj1.values.elementAt(var3))) {
                     return false;
                  }
               }

               return true;
            }
         }
      }
   }

   public boolean equals(Object obj) {
      if (obj == this) {
         return true;
      } else if (!(obj instanceof X509Name) && !(obj instanceof ASN1Sequence)) {
         return false;
      } else {
         DERObject var2 = ((DEREncodable)obj).getDERObject();
         if (this.getDERObject().equals(var2)) {
            return true;
         } else {
            X509Name var10000;
            X509Name var10001;
            try {
               var10000 = this;
               var10001 = getInstance(obj);
            } catch (IllegalArgumentException var11) {
               return false;
            }

            X509Name obj1 = var10001;
            int var13;
            if ((var13 = var10000.ordering.size()) != obj1.ordering.size()) {
               return false;
            } else {
               boolean[] var3 = new boolean[var13];
               int var4;
               int var5;
               byte var6;
               if (this.ordering.elementAt(0).equals(obj1.ordering.elementAt(0))) {
                  var4 = 0;
                  var5 = 1;
                  var6 = (byte)var5;
                  var5 = var13;
               } else {
                  var4 = var13 - 1;
                  var5 = -1;
                  var6 = -1;
               }

               while(var4 != var5) {
                  boolean var7 = false;
                  DERObjectIdentifier var8 = (DERObjectIdentifier)this.ordering.elementAt(var4);
                  String var9 = (String)this.values.elementAt(var4);

                  for(int var10 = 0; var10 < var13; ++var10) {
                     if (!var3[var10] && var8.equals((DERObjectIdentifier)obj1.ordering.elementAt(var10)) && this.equivalentStrings(var9, (String)obj1.values.elementAt(var10))) {
                        var3[var10] = true;
                        var7 = true;
                        break;
                     }
                  }

                  if (!var7) {
                     return false;
                  }

                  var4 += var6;
               }

               return true;
            }
         }
      }
   }

   public int hashCode() {
      Enumeration var2 = ((ASN1Sequence)this.getDERObject()).getObjects();

      int var1;
      for(var1 = 0; var2.hasMoreElements(); var1 ^= var2.nextElement().hashCode()) {
      }

      return var1;
   }

   public String toString(boolean reverse, Hashtable oidSymbols) {
      StringBuffer var3;
      var3 = new StringBuffer.<init>();
      Vector var4;
      var4 = new Vector.<init>();
      boolean var5 = true;
      StringBuffer var6 = null;

      for(int var7 = 0; var7 < this.ordering.size(); ++var7) {
         DERObjectIdentifier var8;
         String var9;
         if ((Boolean)this.added.elementAt(var7)) {
            var6.append('+');
            var8 = (DERObjectIdentifier)this.ordering.elementAt(var7);
            var9 = (String)this.values.elementAt(var7);
            this.appendValue(var6, oidSymbols, var8, var9);
         } else {
            StringBuffer var10002 = var6 = new StringBuffer;
            var6.<init>();
            var8 = (DERObjectIdentifier)this.ordering.elementAt(var7);
            var9 = (String)this.values.elementAt(var7);
            this.appendValue(var10002, oidSymbols, var8, var9);
            var4.addElement(var6);
         }
      }

      int var10;
      if (reverse) {
         for(var10 = var4.size() - 1; var10 >= 0; --var10) {
            if (var5) {
               var5 = false;
            } else {
               var3.append(',');
            }

            var3.append(var4.elementAt(var10).toString());
         }
      } else {
         for(var10 = 0; var10 < var4.size(); ++var10) {
            if (var5) {
               var5 = false;
            } else {
               var3.append(',');
            }

            var3.append(var4.elementAt(var10).toString());
         }
      }

      return var3.toString();
   }

   public String toString() {
      return this.toString(DefaultReverse, DefaultSymbols);
   }
}
